@@ -20,6 +20,8 @@ import re
 from pathlib import Path
 from typing import Optional, Tuple
 
+import pytest
+
 from b2sdk.v2 import B2_ACCOUNT_INFO_ENV_VAR, SSE_C_KEY_ID_FILE_INFO_KEY_NAME, UNKNOWN_FILE_RETENTION_SETTING, EncryptionMode, EncryptionSetting, FileRetentionSetting, LegalHold, RetentionMode, fix_windows_path_limit
 
 from b2.console_tool import current_time_millis
@@ -1992,7 +1994,6 @@ def test_replication_basic(b2_api, b2_tool, bucket_name):
             'create-bucket',
             source_bucket_name,
             'allPublic',
-            '--fileLockEnabled',
             '--replication',
             source_replication_configuration_json,
             *get_bucketinfo(),
@@ -2007,6 +2008,12 @@ def test_replication_basic(b2_api, b2_tool, bucket_name):
     # test that source bucket is not mentioned as replication destination
     assert source_bucket['replication'].get('asReplicationDestination') is None
 
+    # ---------------- attempt enabling object lock  ----------------
+    b2_tool.should_fail(
+        ['update-bucket', source_bucket_name, '--fileLockEnabled'],
+        'ERROR: Operation not supported for buckets with source replication'
+    )
+
     # ---------------- remove replication source ----------------
 
     no_replication_configuration = {
@@ -2285,7 +2292,7 @@ def test_replication_monitoring(b2_tool, bucket_name, b2_api):
                         "source_has_hide_marker": None,
                         "source_has_large_metadata": None,
                         "source_has_legal_hold": None,
-                        "source_has_sse_c_enabled": None,
+                        "source_encryption_mode": None,
                         "source_replication_status": None,
                     }
                 ],
@@ -2300,7 +2307,7 @@ def test_replication_monitoring(b2_tool, bucket_name, b2_api):
                         "source_has_hide_marker": False,
                         "source_has_large_metadata": False,
                         "source_has_legal_hold": True,
-                        "source_has_sse_c_enabled": False,
+                        "source_encryption_mode": 'none',
                         "source_replication_status": first,
                     }, {
                         "count": 1,
@@ -2311,7 +2318,7 @@ def test_replication_monitoring(b2_tool, bucket_name, b2_api):
                         "source_has_hide_marker": False,
                         "source_has_large_metadata": False,
                         "source_has_legal_hold": False,
-                        "source_has_sse_c_enabled": False,
+                        "source_encryption_mode": 'SSE-B2',
                         "source_replication_status": second,
                     }, {
                         "count": 1,
@@ -2322,7 +2329,7 @@ def test_replication_monitoring(b2_tool, bucket_name, b2_api):
                         "source_has_hide_marker": False,
                         "source_has_large_metadata": False,
                         "source_has_legal_hold": False,
-                        "source_has_sse_c_enabled": True,
+                        "source_encryption_mode": 'SSE-C',
                         "source_replication_status": None,
                     }, {
                         "count": 1,
@@ -2333,7 +2340,7 @@ def test_replication_monitoring(b2_tool, bucket_name, b2_api):
                         "source_has_hide_marker": False,
                         "source_has_large_metadata": False,
                         "source_has_legal_hold": True,
-                        "source_has_sse_c_enabled": True,
+                        "source_encryption_mode": 'SSE-C',
                         "source_replication_status": None,
                     }
                 ]
@@ -2343,6 +2350,47 @@ def test_replication_monitoring(b2_tool, bucket_name, b2_api):
     b2_api.clean_bucket(source_bucket_name)
 
 
+def test_enable_file_lock_first_retention_second(b2_tool, b2_api, bucket_name):
+    # enable file lock only
+    b2_tool.should_succeed(['update-bucket', bucket_name, '--fileLockEnabled'])
+
+    # set retention with file lock already enabled
+    b2_tool.should_succeed(
+        [
+            'update-bucket', bucket_name, '--defaultRetentionMode', 'compliance',
+            '--defaultRetentionPeriod', '7 days'
+        ]
+    )
+
+    # attempt to re-enable should be a noop
+    b2_tool.should_succeed(['update-bucket', bucket_name, '--fileLockEnabled'])
+
+    b2_api.clean_bucket(bucket_name)
+
+
+def test_enable_file_lock_and_set_retention_at_once(b2_tool, b2_api, bucket_name):
+    # attempt setting retention without file lock enabled
+    b2_tool.should_fail(
+        [
+            'update-bucket', bucket_name, '--defaultRetentionMode', 'compliance',
+            '--defaultRetentionPeriod', '7 days'
+        ], 'ERROR: The bucket is not file lock enabled \(bucket_missing_file_lock\)'
+    )
+
+    # enable file lock and set retention at once
+    b2_tool.should_succeed(
+        [
+            'update-bucket', bucket_name, '--defaultRetentionMode', 'compliance',
+            '--defaultRetentionPeriod', '7 days', '--fileLockEnabled'
+        ]
+    )
+
+    # attempt to re-enable should be a noop
+    b2_tool.should_succeed(['update-bucket', bucket_name, '--fileLockEnabled'])
+
+    b2_api.clean_bucket(bucket_name)
+
+
 def _assert_file_lock_configuration(
     b2_tool,
     file_id,
